libname e 'C:/Users/u0106491/Desktop/Datasets';

data retweeted;
  set e.Epilepsy;
run;

data received;
  set e.Moerzeke;
run;

/*Analysis of epilepsy*/
/*DE - UNIVARIATE*/
proc nlmixed data = retweeted;
  parms beta0=-1 beta0X=-0.4 beta1=-0.0134 beta1X=-0.018;
  if (trt = 0) then eta = beta0 + beta1*time;
  else if (trt = 1) then eta = (beta0+beta0X)  + (beta1+beta1X)*time;
  mu = exp(eta);
  ll  = eta*y - log(mu + 1)*y + log(1 - (mu/(mu+1)));
  model y ~ general(ll);
  predict mu out=nlmixnew1;
  estimate 'difference in slope' beta1X;
  estimate 'ratio of slopes' 1+(beta1X/beta1);
run;

/*DW - UNIVARIATE*/
proc nlmixed data = retweeted;
  parms beta0=-1 beta0X=-0.4 beta1=-0.0134 beta1X=-0.018 rho=1;
  if (trt = 0) then eta = beta0 + beta1*time;
  else if (trt = 1) then eta = (beta0+beta0X)  + (beta1+beta1X)*time;
  lambda = log(exp(eta)+1) - log(exp(eta));
  if y=0 then prob = 1 - exp(-1*lambda);
  else prob=exp(-1*lambda*(y**rho))-exp(-1*lambda*((y+1)**rho));
  ll  = log(prob);
  model y ~ general(ll);
  predict lambda out=nlmixnew2;
  estimate 'difference in slope' beta1X;
  estimate 'ratio of slopes' 1+(beta1X/beta1);
run;

/*DE - HIERACHICAL (random intercept)*/
proc nlmixed data = retweeted;
  parms beta0=-1 beta0X=-0.4 beta1=-0.0134 beta1X=-0.018 sigma=1;
  if (trt = 0) then eta = beta0 +u+ beta1*time;
  else if (trt = 1) then eta = (beta0+beta0X)  +u+ (beta1+beta1X)*time;
  expeta = exp(eta);
  ll  = eta*y - log(expeta + 1)*y + log(1 - (expeta/(expeta+1)));
  model y ~ general(ll);
  random u ~ normal(0,sigma**2) subject=id;
  estimate 'difference in slope' beta1X;
  estimate 'ratio of slopes' 1+(beta1X/beta1);
run;

/*DW - HIERARCHICAL (random intercept)*/
proc nlmixed data = retweeted;
  parms beta0=-1 beta0X=-0.4 beta1=-0.0134 beta1X=-0.018 sigma=1 rho=0.2;
  if (trt = 0) then eta = beta0 +u+ beta1*time;
  else if (trt = 1) then eta = (beta0+beta0X)  +u+ (beta1+beta1X)*time;
  lambda = log(exp(eta)+1) - log(exp(eta));
  if y=0 then prob = 1 - exp(-1*lambda);
  else prob=exp(-1*lambda*(y**rho))-exp(-1*lambda*((y+1)**rho));
  ll  = log(prob);
  model y ~ general(ll);
  random u ~ normal(0,sigma**2) subject=id;
  estimate 'difference in slope' beta1X;
  estimate 'ratio of slopes' 1+(beta1X/beta1);
run;

/*DW - HIERARCHICAL (random slope - uncorrelated)*/
proc nlmixed data = retweeted;
  parms beta0=-1 beta0X=-0.4 beta1=-0.0134 beta1X=-0.018 sigma1=1 sigma2=1 rho=0.2;
  cov=0;
  if (trt = 0) then eta = beta0 +u+ beta1*time + v*time;
  else if (trt = 1) then eta = (beta0+beta0X)  +u+ (beta1+beta1X)*time + v*time;
  lambda = log(exp(eta)+1) - log(exp(eta));
  if y=0 then prob = 1 - exp(-1*lambda);
  else prob=exp(-1*lambda*(y**rho))-exp(-1*lambda*((y+1)**rho));
  ll  = log(prob);
  model y ~ general(ll);
  random u v ~ normal([0,0],[sigma1**2,cov,sigma2**2]) subject=id;
  estimate 'difference in slope' beta1X;
  estimate 'ratio of slopes' 1+(beta1X/beta1);
run;

/*DW - HIERARCHICAL (random slope - correlated)*/
proc nlmixed data = retweeted;
  parms beta0=-1 beta0X=-0.4 beta1=-0.0134 beta1X=-0.018 sigma1=1 sigma2=1 cov=0.4 rho=0.2;
  if (trt = 0) then eta = beta0 +u+ beta1*time + v*time;
  else if (trt = 1) then eta = (beta0+beta0X)  +u+ (beta1+beta1X)*time + v*time;
  lambda = log(exp(eta)+1) - log(exp(eta));
  if y=0 then prob = 1 - exp(-1*lambda);
  else prob=exp(-1*lambda*(y**rho))-exp(-1*lambda*((y+1)**rho));
  ll  = log(prob);
  model y ~ general(ll);
  random u v ~ normal([0,0],[sigma1**2,cov,sigma2**2]) subject=id;
  estimate 'difference in slope' beta1X;
  estimate 'ratio of slopes' 1+(beta1X/beta1);
run;

/*Analysis of Moerzeke*/
/*DE - UNIVARIATE*/
proc nlmixed data = received;
  parms beta0=-1 beta0X=-0.4 beta0XX=-0.4 beta1=-0.0134 beta1X=-0.018 beta1XX=-0.018;
  if FamilyMember='F' then
  eta=beta0XX + beta1XX*SexNum;
  else if FamilyMember='M' then
  eta=beta0X + beta1X*SexNum;
  else eta=beta0 + beta1*SexNum;
  mu = exp(eta);
  ll  = eta*y - log(mu + 1)*y + log(1 - (mu/(mu+1)));
  model y ~ general(ll);
  predict mu out=nlmixnew1;
run;

/*DW - UNIVARIATE*/
proc nlmixed data = received;
  parms beta0=-1 beta0X=-0.4 beta0XX=-0.4 beta1=-0.0134 beta1X=-0.018 beta1XX=-0.018 rho=1;
  if FamilyMember='F' then
  eta=beta0XX + beta1XX*SexNum;
  else if FamilyMember='M' then
  eta=beta0X + beta1X*SexNum;
  else eta=beta0 + beta1*SexNum;	
  lambda = log(exp(eta)+1) - log(exp(eta));
  if y=0 then prob = 1 - exp(-1*lambda);
  else prob=exp(-1*lambda*(y**rho))-exp(-1*lambda*((y+1)**rho));
  ll  = log(prob);
  model y ~ general(ll);
  predict lambda out=nlmixnew2;
run;

/*DE - HIERACHICAL (random intercept)*/
proc nlmixed data = received;
  parms beta0=-1 beta0X=-0.4 beta0XX=-0.4 beta1=-0.0134 beta1X=-0.018 beta1XX=-0.018 sigma=1;
  if FamilyMember='F' then
  eta=beta0XX + beta1XX*SexNum + u;
  else if FamilyMember='M' then
  eta=beta0X + beta1X*SexNum + u;
  else eta=beta0 + beta1*SexNum + u;	
  expeta = exp(eta);
  ll  = eta*y - log(expeta + 1)*y + log(1 - (expeta/(expeta+1)));
  model y ~ general(ll);
  random u ~ normal(0,exp(sigma)**2) subject=id;
  estimate 'random intercept' exp(sigma);
run;

/*DW - HIERARCHICAL (random intercept)*/
proc nlmixed data = received TECH=NRRIDG maxiter=1000 maxfunc=5000;
  parms beta0=-1 beta0X=-0.4 beta0XX=-0.4 beta1=-0.0134 beta1X=-0.018 beta1XX=-0.018 sigma=1 rho=1;
  if FamilyMember='F' then
  eta=beta0XX + beta1XX*SexNum + u;
  else if FamilyMember='M' then
  eta=beta0X + beta1X*SexNum + u;
  else eta=beta0 + beta1*SexNum + u;	
  lambda = log(exp(eta)+1) - log(exp(eta));
  if y=0 then prob = 1 - exp(-1*lambda);
  else prob=exp(-1*lambda*(y**rho))-exp(-1*lambda*((y+1)**rho));
  ll  = log(prob);
  model y ~ general(ll);
  random u ~ normal(0,exp(sigma)**2) subject=id;
  estimate 'random intercept' exp(sigma);
run;
